Exception: Clickwrap::ImmutableEvidenceError

Inherits:
Error
  • Object
show all
Defined in:
lib/clickwrap/errors.rb

Overview

Raised when ordinary Active Record mutation is attempted against evidence whose only permitted changes are named, audited lifecycle transitions.