Class: Clickwrap::Import::FinePrint::ContractMapping

Inherits:
Data
  • Object
show all
Defined in:
lib/clickwrap/import/fine_print.rb

Overview

One FinePrint contract version, and whether this application has a published Clickwrap document version that corresponds to it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#document_keyObject (readonly)

Returns the value of attribute document_key

Returns:

  • (Object)

    the current value of document_key



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def document_key
  @document_key
end

#nameObject (readonly)

Returns the value of attribute name

Returns:

  • (Object)

    the current value of name



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def name
  @name
end

#published_version_idObject (readonly)

Returns the value of attribute published_version_id

Returns:

  • (Object)

    the current value of published_version_id



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def published_version_id
  @published_version_id
end

#signature_countObject (readonly)

Returns the value of attribute signature_count

Returns:

  • (Object)

    the current value of signature_count



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def signature_count
  @signature_count
end

#titleObject (readonly)

Returns the value of attribute title

Returns:

  • (Object)

    the current value of title



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def title
  @title
end

#versionObject (readonly)

Returns the value of attribute version

Returns:

  • (Object)

    the current value of version



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def version
  @version
end

#version_labelObject (readonly)

Returns the value of attribute version_label

Returns:

  • (Object)

    the current value of version_label



62
63
64
# File 'lib/clickwrap/import/fine_print.rb', line 62

def version_label
  @version_label
end

Instance Method Details

#published?Boolean

Returns:

  • (Boolean)


64
# File 'lib/clickwrap/import/fine_print.rb', line 64

def published? = !published_version_id.nil?