Exception: Clickwrap::PresentationInvalid

Inherits:
CaptureRefused show all
Defined in:
lib/clickwrap/errors.rb

Overview

Raised when the submitted presentation token is missing, malformed, signed with a different key, expired, or bound to a different actor, tenant, subject, policy, or revision than the one being captured.

Direct Known Subclasses

PresentationExpired

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from CaptureRefused

#user_facing_message

Constructor Details

#initialize(message = nil, result: nil) ⇒ PresentationInvalid

Returns a new instance of PresentationInvalid.



61
62
63
64
# File 'lib/clickwrap/errors.rb', line 61

def initialize(message = nil, result: nil)
  @result = result
  super(message || result&.message || "The presentation could not be verified")
end

Instance Attribute Details

#resultObject (readonly)

Returns the value of attribute result.



59
60
61
# File 'lib/clickwrap/errors.rb', line 59

def result
  @result
end