Exception: Clickwrap::RemediationInvalid

Inherits:
Error
  • Object
show all
Defined in:
lib/clickwrap/errors.rb

Overview

Raised when a signed in-place remediation context is missing, expired, belongs to a different actor/tenant/policy, or names a resource that can no longer be resolved and authorized.

Direct Known Subclasses

RemediationNotAuthorized