Exception: Clickwrap::RequestEvidenceUnavailable
- Defined in:
- lib/clickwrap/errors.rb
Overview
Raised when a policy requires IP address, browser user-agent, or IP geolocation evidence and it could not be resolved.
Raised when a policy requires IP address, browser user-agent, or IP geolocation evidence and it could not be resolved.