Class: Clickwrap::Import::FinePrint::ContractMapping
- Inherits:
-
Data
- Object
- Data
- Clickwrap::Import::FinePrint::ContractMapping
- Defined in:
- lib/clickwrap/import/fine_print.rb
Overview
One FinePrint contract version, and whether this application has a published Clickwrap document version that corresponds to it.
Instance Attribute Summary collapse
-
#document_key ⇒ Object
readonly
Returns the value of attribute document_key.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#published_version_id ⇒ Object
readonly
Returns the value of attribute published_version_id.
-
#signature_count ⇒ Object
readonly
Returns the value of attribute signature_count.
-
#title ⇒ Object
readonly
Returns the value of attribute title.
-
#version ⇒ Object
readonly
Returns the value of attribute version.
-
#version_label ⇒ Object
readonly
Returns the value of attribute version_label.
Instance Method Summary collapse
Instance Attribute Details
#document_key ⇒ Object (readonly)
Returns the value of attribute document_key
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def document_key @document_key end |
#name ⇒ Object (readonly)
Returns the value of attribute name
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def name @name end |
#published_version_id ⇒ Object (readonly)
Returns the value of attribute published_version_id
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def published_version_id @published_version_id end |
#signature_count ⇒ Object (readonly)
Returns the value of attribute signature_count
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def signature_count @signature_count end |
#title ⇒ Object (readonly)
Returns the value of attribute title
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def title @title end |
#version ⇒ Object (readonly)
Returns the value of attribute version
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def version @version end |
#version_label ⇒ Object (readonly)
Returns the value of attribute version_label
62 63 64 |
# File 'lib/clickwrap/import/fine_print.rb', line 62 def version_label @version_label end |
Instance Method Details
#published? ⇒ Boolean
64 |
# File 'lib/clickwrap/import/fine_print.rb', line 64 def published? = !published_version_id.nil? |