Exception: Clickwrap::PresentationInvalid
- Inherits:
-
CaptureRefused
- Object
- StandardError
- Error
- CaptureRefused
- Clickwrap::PresentationInvalid
- Defined in:
- lib/clickwrap/errors.rb
Overview
Raised when the submitted presentation token is missing, malformed, signed with a different key, expired, or bound to a different actor, tenant, subject, policy, or revision than the one being captured.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#result ⇒ Object
readonly
Returns the value of attribute result.
Instance Method Summary collapse
-
#initialize(message = nil, result: nil) ⇒ PresentationInvalid
constructor
A new instance of PresentationInvalid.
Methods inherited from CaptureRefused
Constructor Details
#initialize(message = nil, result: nil) ⇒ PresentationInvalid
Returns a new instance of PresentationInvalid.
61 62 63 64 |
# File 'lib/clickwrap/errors.rb', line 61 def initialize( = nil, result: nil) @result = result super( || result&. || "The presentation could not be verified") end |
Instance Attribute Details
#result ⇒ Object (readonly)
Returns the value of attribute result.
59 60 61 |
# File 'lib/clickwrap/errors.rb', line 59 def result @result end |